==> fusionforge_5.1.1.orig.tar.gz: fusionforge-5.1.1/plugins/wiki/www/locale/ja/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%s bytes"] = "%s バイト";
$locale["%s bytes written"] = "%s  バイト書き込みました。";
$locale["%s is empty."] = "%s が空です。";
$locale["%s: Bad action"] = "%s: 正しくない操作です。";
$locale["%s: Can't open dba database"] = "%s: dba データベースをオープン出来ません。";
$locale["%s: file not found"] = "%s: ファイルが見つかりません。";
$locale["%s: not defined"] = "%s: 未定義でした。";
$locale["'%s': Bad page name"] = "'%s': ページ名が正しくありません";
$locale["(diff)"] = "(差分)";
$locale["<no matches>"] = "<一致しません>";
$locale["<none>"] = "<なし>";
$locale["<system language>"] = "<システム言語>";
$locale["<system theme>"] = "<システムテーマ>";
$locale["Action page"] = "操作ページ";
$locale["Adjust"] = "調整";
$locale["Admin"] = "管理";
$locale["AllPages"] = "全ページ";
$locale["AllUsers"] = "全ユーザー";
$locale["Allowed protocols"] = "許可するプロトコル一覧";
$locale["Appearance"] = "外観";
$locale["Application name"] = "アプリケーション名";
$locale["Arguments"] = "引数一覧";
$locale["Auth Level"] = "認証レベル";
$locale["Auth Method"] = "認証方法";
$locale["Available plugins"] = "有効なプラグイン一覧";
$locale["Bad Version"] = "バージョンが正しくありません。";
$locale["Blog page"] = "Blogページ";
$locale["Browsing pages"] = "ページを閲覧中です。";
$locale["Cache statistics"] = "キャッシュ統計";
$locale["Calendar"] = "カレンダー";
$locale["Cannot create directory '%s'"] = "ディレクトリ '%s' を作成出来ません。";
$locale["Change Password"] = "パスワード変更";
$locale["Change country"] = "国名変更";
$locale["Comment"] = "コメント";
$locale["Complete."] = "完了しました。";
$locale["Contents"] = "コンテンツ";
$locale["Count"] = "カウント";
$locale["Create: %s"] = "作成: %s";
$locale["Creating pages"] = "ページを作成しています。";
$locale["Current Language"] = "現在の言語";
$locale["Current language: '%s'"] = "現在の言語: %s";
$locale["Current theme: '%s'"] = "現在のテーマ: %s";
$locale["Date Format"] = "データフォーマット";
$locale["DebugInfo"] = "デバグ情報";
$locale["Default theme: '%s'"] = "デフォルトテーマ: %s";
$locale["Describe %s here."] = "ここに%sを記述します。";
$locale["Description"] = "説明";
$locale["Dialog"] = "ダイアログ";
$locale["Diff"] = "差分";
$locale["Diff: %s"] = "差分: %s";
$locale["Diffing pages"] = "ページの差分を出力しています。";
$locale["Dump Pages as XHTML"] = "XHTMLで出力";
$locale["Dumping html pages"] = "HTMLページを出力しています。";
$locale["Dumping serial pages"] = "シリアライズページを出力しています。";
$locale["E-Mail"] = "メール";
$locale["Edit"] = "編集";
$locale["Edit %s"] = "%s を編集";
$locale["Edit Area Size"] = "編集エリアのサイズ";
$locale["Edit Old Revision"] = "古いリビジョンを編集する";
$locale["Edit aborted."] = "編集を中断しました。";
$locale["Edit metadata for %s"] = "%s のMETAデータの編集";
$locale["Edit: %s"] = "編集: %s";
$locale["EditMetaData"] = "METAデータの編集";
$locale["Editing pages"] = "ページを編集しています。";
$locale["Email not yet verified."] = "メールアドレスを確認出来ませんでした。";
$locale["Email verified."] = "メールアドレスを確認出来ました。";
$locale["Empty pagename!"] = "ページ名が未指定です!";
$locale["Enter your UserId to sign in"] = "ユーザーIDを入力してサインインしてください。";
$locale["Fatal PhpWiki Error"] = "致命的なPhpWikiのエラーです。";
$locale["FindPage"] = "ページ検索";
$locale["First"] = "最初へ";
$locale["FullTextSearch"] = "全文検索";
$locale["H"] = "高さ";
$locale["Height"] = "高さ";
$locale["History of changes."] = "変更履歴";
$locale["Hit statistics"] = "ヒット統計";
$locale["Hits"] = "ヒット";
$locale["Hits:"] = "ヒット数:";
$locale["HomePage"] = "ホームページ";
$locale["Included from %s"] = "%s から読込まれました。";
$locale["Index"] = "インデックス";
$locale["Inline images"] = "インライン画像一覧";
$locale["InterWiki Address"] = "InterWikiアドレス";
$locale["InterWikiSearch"] = "InterWiki検索";
$locale["Invalid password or userid."] = "ユーザーIDかパスワードが無効です。";
$locale["Language"] = "言語";
$locale["Last"] = "最後へ";
$locale["Last Author"] = "最終編集者";
$locale["Last Modified"] = "最終更新日時";
$locale["Last Summary"] = "最終要約";
$locale["List PageHistory for %s"] = "%s のページ履歴一覧";
$locale["Load File"] = "ファイル読込み";
$locale["Loading '%s'"] = "'%s' を読込み中です。";
$locale["Loading files"] = "ファイルを読込み中です。";
$locale["Lock Page"] = "ページロック";
$locale["Locked"] = "ロックしました";
$locale["Locking pages"] = "ページをロック中です。";
$locale["Login"] = "ログイン";
$locale["MIME file %s"] = "MIMEファイル %s";
$locale["Markup"] = "マークアップ";
$locale["Markup cache purged!"] = "マークアップキャッシュを破棄しました!";
$locale["Markup:"] = "マークアップ:";
$locale["Name"] = "名称";
$locale["New comment."] = "新規コメント";
$locale["New password"] = "新規パスワード";
$locale["Next"] = "次へ";
$locale["Next Month"] = "次の月";
$locale["No changes found"] = "変更点が見つかりませんでした。";
$locale["No changes."] = "変更しませんでした。";
$locale["No revisions found"] = "リビジョンが見つかりません。";
$locale["None"] = "なし";
$locale["Note:"] = "ノート:";
$locale["Okay"] = "おっけー";
$locale["OldStyleTable"] = "旧スタイルのテーブル";
$locale["PHP syntax highlighting"] = "PHP構文ハイライト";
$locale["Page Locked"] = "ページをロックしました。";
$locale["Page Name"] = "ページ名";
$locale["Page Type:"] = "ページの種類<:";
$locale["Page Version:"] = "ページバージョン:";
$locale["Page now locked."] = "ページはロック中です。";
$locale["Page now unlocked."] = "ページはロック解除中です。";
$locale["Page statistics"] = "ページ統計";
$locale["PageGroup"] = "ページグループ";
$locale["PageHistory"] = "ページ履歴";
$locale["PageHistory for %s"] = "%s のページ履歴";
$locale["PageInfo"] = "ページ情報";
$locale["Password:"] = "パスワード:";
$locale["Personal language:"] = "個人言語";
$locale["Personal theme:"] = "個人テーマ";
$locale["PhotoAlbum"] = "フォトアルバム";
$locale["PhpHighlight"] = "PHPハイライト";
$locale["Please continue editing.  (You'll find your %s at the bottom of the page.)"] = "編集を続けて下さい。 (%s のページの下部も見てください)";
$locale["Plugin"] = "プラグイン";
$locale["Plugin %s disabled."] = "プラグイン %s は無効になっています。";
$locale["Plugin %s failed."] = "プラグイン %s が失敗しました。";
$locale["PluginManager"] = "プラグイン管理";
$locale["Plugins"] = "プラグイン一覧";
$locale["PrevNext"] = "前後";
$locale["Preview"] = "プレビューする";
$locale["Preview only!  Changes not saved."] = "プレビューしているだけです! まだ保存はされていません。";
$locale["Previous"] = "前へ";
$locale["Previous Author"] = "前の編集者";
$locale["Previous Month"] = "前の月";
$locale["Previous Revision"] = "前のリビジョン";
$locale["Printer"] = "プリンター";
$locale["Purge Markup Cache"] = "マークアップキャッシュの破棄";
$locale["RandomPage"] = "ランダムページ";
$locale["Raw HTML"] = "生のHTML";
$locale["RecentChanges"] = "変更履歴";
$locale["Redirect"] = "転送";
$locale["References"] = "参照一覧";
$locale["Remove Page"] = "ページ削除";
$locale["Remove selected pages"] = "選択ページを全て削除";
$locale["Removing pages"] = "ページを削除中です。";
$locale["Return to %s"] = "%s に戻る";
$locale["Revision Not Found"] = "リビジョンが見つかりません";
$locale["Save"] = "保存する";
$locale["Score"] = "スコア";
$locale["Search"] = "検索";
$locale["See %s"] = "%s を参照";
$locale["See: %s"] = "参照: %s";
$locale["Select: "] = "選択:";
$locale["Serialized file %s"] = "シリアライズファイル %s";
$locale["Sidebar"] = "スライドバー";
$locale["Sign In"] = "サインイン";
$locale["Sign Out"] = "サインサウト";
$locale["SiteMap"] = "サイトマップ";
$locale["Size:"] = "サイズ:";
$locale["Sort by %s"] = "%sでソートします。";
$locale["Sound Score"] = "サウンドスコア";
$locale["Status:"] = "状況:";
$locale["Submit"] = "送信";
$locale["Submit country"] = "国名送信";
$locale["Submit location"] = "所在地変更";
$locale["Subpage"] = "サブページ";
$locale["Summary"] = "要約";
$locale["Supported languages"] = "サポート言語一覧";
$locale["Supported themes"] = "サポートテーマ一覧";
$locale["Synopsis"] = "要約";
$locale["SystemInfo"] = "システム情報";
$locale["Theme"] = "テーマ";
$locale["Time Zone"] = "タイムゾーン";
$locale["Title Search"] = "タイトル検索";
$locale["TitleSearch"] = "タイトル検索";
$locale["Today"] = "今日";
$locale["Top & bottom toolbars"] = "上部と下部のツールバー";
$locale["Total %d plugins: "] = "合計 %d プラグイン";
$locale["Total of %d themes: "] = "総テーマ数: %d";
$locale["Type it again"] = "もう一度入力";
$locale["Unlock Page"] = "ページロック解除";
$locale["Unlocking pages"] = "ページのロックを解除中です。";
$locale["Update Preferences"] = "設定を更新しました";
$locale["Upload"] = "アップロード";
$locale["Uploading %s"] = "%s をアップロード中です。";
$locale["Use old markup"] = "古いマークアップを使用";
$locale["User page"] = "ユーザーページ";
$locale["User statistics"] = "ユーザー統計";
$locale["UserId"] = "ユーザーID";
$locale["UserId:"] = "ユーザーID:";
$locale["UserPreferences"] = "ユーザー設定";
$locale["Using directory '%s'"] = "ディレクトリ '%s' を使用しています。";
$locale["Version"] = "バージョン";
$locale["Version %d"] = "バージョン %d";
$locale["Version %s"] = "バージョン %s";
$locale["View Source"] = "ソースを見る";
$locale["View Source: %s"] = "ソースを見る: %s";
$locale["View the current version"] = "現在のバージョンを表示する";
$locale["W"] = "幅";
$locale["Warning: You are editing an old revision."] = "警告: あなたは古いリビジョンを編集しています。";
$locale["Width"] = "幅";
$locale["Wiki Name"] = "Wiki名";
$locale["WikiForm: %s: unknown action"] = "WikiForm: '%s' は未知の操作です。";
$locale["Your E-Mail:"] = "あなたのメールアドレス:";
$locale["cached pagedata:"] = "ページデータをキャッシュ:";
$locale["cached versiondata:"] = "バージョンデータをキャッシュ:";
$locale["compare revisions"] = "リビジョン比較";
$locale["current version"] = "現在のバージョン";
$locale["diff"] = "差分";
$locale["edit area"] = "編集エリア";
$locale["from %s"] = "%s から";
$locale["home page"] = "ホームページ";
$locale["locked"] = "ロックしました";
$locale["max: %d"] = "最大: %d";
$locale["no cache used"] = "キャッシュを使いません";
$locale["plain file %s"] = "プレインファイル %s";
$locale["previous revision"] = "前のリビジョン";
$locale["saved as %s"] = "%s を保存しました。";
$locale["today"] = "今日";
$locale["too long"] = "長すぎます。";
$locale["use this plugin"] = "このプラグインを使う";
$locale["version %d"] = "バージョン %d";
$locale["version %s"] = "バージョン %s";
$locale["yesterday"] =
   "昨日";

?>

==> fusionforge_5.2~rc1+1.tar.gz: fusionforge-5.2~rc1+1/plugins/wiki/www/locale/ja/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%s bytes"] = "%s バイト";
$locale["%s bytes written"] = "%s  バイト書き込みました。";
$locale["%s is empty."] = "%s が空です。";
$locale["%s: Bad action"] = "%s: 正しくない操作です。";
$locale["%s: Can't open dba database"] = "%s: dba データベースをオープン出来ません。";
$locale["%s: file not found"] = "%s: ファイルが見つかりません。";
$locale["%s: not defined"] = "%s: 未定義でした。";
$locale["'%s': Bad page name"] = "'%s': ページ名が正しくありません";
$locale["(diff)"] = "(差分)";
$locale["<no matches>"] = "<一致しません>";
$locale["<none>"] = "<なし>";
$locale["<system language>"] = "<システム言語>";
$locale["<system theme>"] = "<システムテーマ>";
$locale["Add %s"] = "ヒット数";
$locale["Adjust"] = "調整";
$locale["Admin"] = "管理";
$locale["AllPages"] = "全ページ";
$locale["AllUsers"] = "全ユーザー";
$locale["Allowed protocols"] = "許可するプロトコル一覧";
$locale["Appearance"] = "外観";
$locale["Application name"] = "アプリケーション名";
$locale["Arguments"] = "引数一覧";
$locale["Auth Level"] = "認証レベル";
$locale["Auth Method"] = "認証方法";
$locale["Author"] = "編集者";
$locale["Available plugins"] = "有効なプラグイン一覧";
$locale["Bad Version"] = "バージョンが正しくありません。";
$locale["Blog page"] = "Blogページ";
$locale["Browsing pages"] = "ページを閲覧中です。";
$locale["Cache statistics"] = "キャッシュ統計";
$locale["Calendar"] = "カレンダー";
$locale["Cannot create directory '%s'"] = "ディレクトリ '%s' を作成出来ません。";
$locale["Change Password"] = "パスワード変更";
$locale["Change country"] = "国名変更";
$locale["Comment"] = "コメント";
$locale["Complete."] = "完了しました。";
$locale["Content"] = "コンテンツ";
$locale["Contents"] = "コンテンツ";
$locale["Count"] = "カウント";
$locale["Create: %s"] = "作成: %s";
$locale["Creating pages"] = "ページを作成しています。";
$locale["Current Language"] = "現在の言語";
$locale["Current language: '%s'"] = "現在の言語: %s";
$locale["Current theme: '%s'"] = "現在のテーマ: %s";
$locale["Date Format"] = "データフォーマット";
$locale["DebugInfo"] = "デバグ情報";
$locale["Default theme: '%s'"] = "デフォルトテーマ: %s";
$locale["Describe %s here."] = "ここに%sを記述します。";
$locale["Description"] = "説明";
$locale["Dialog"] = "ダイアログ";
$locale["Diff"] = "差分";
$locale["Diff: %s"] = "差分: %s";
$locale["Diffing pages"] = "ページの差分を出力しています。";
$locale["Dump Pages as XHTML"] = "XHTMLで出力";
$locale["Dump pages as XHTML"] = "XHTMLで出力";
$locale["Dumping html pages"] = "HTMLページを出力しています。";
$locale["Dumping serial pages"] = "シリアライズページを出力しています。";
$locale["Edit"] = "編集";
$locale["Edit %s"] = "%s を編集";
$locale["Edit Area Size"] = "編集エリアのサイズ";
$locale["Edit Old Revision"] = "古いリビジョンを編集する";
$locale["Edit aborted."] = "編集を中断しました。";
$locale["Edit metadata for %s"] = "%s のMETAデータの編集";
$locale["Edit this page"] = "ページを編集しています。";
$locale["Edit: %s"] = "編集: %s";
$locale["EditMetaData"] = "METAデータの編集";
$locale["Edited by: %s"] = "編集: %s";
$locale["Editing pages"] = "ページを編集しています。";
$locale["Email not yet verified."] = "メールアドレスを確認出来ませんでした。";
$locale["Email verified."] = "メールアドレスを確認出来ました。";
$locale["Empty pagename!"] = "ページ名が未指定です!";
$locale["Enter your UserId to sign in"] = "ユーザーIDを入力してサインインしてください。";
$locale["Fatal PhpWiki Error"] = "致命的なPhpWikiのエラーです。";
$locale["File '%s' not found."] = "%s: ファイルが見つかりません。";
$locale["FindPage"] = "ページ検索";
$locale["First"] = "最初へ";
$locale["FullTextSearch"] = "全文検索";
$locale["GooglePlugin"] = "Googleプラグイン";
$locale["H"] = "高さ";
$locale["Height"] = "高さ";
$locale["Hide %s"] = "ヒット数";
$locale["History of changes."] = "変更履歴";
$locale["Hit statistics"] = "ヒット統計";
$locale["Hits"] = "ヒット";
$locale["HomePage"] = "ホームページ";
$locale["Included from %s"] = "%s から読込まれました。";
$locale["Index"] = "インデックス";
$locale["Inline images"] = "インライン画像一覧";
$locale["Insert Plugin"] = "プラグインを追加";
$locale["InterWiki Address"] = "InterWikiアドレス";
$locale["InterWikiSearch"] = "InterWiki検索";
$locale["Invalid password or userid."] = "ユーザーIDかパスワードが無効です。";
$locale["Language"] = "言語";
$locale["Last"] = "最後へ";
$locale["Last Author"] = "最終編集者";
$locale["Last Modified"] = "最終更新日時";
$locale["Last Summary"] = "最終要約";
$locale["LdapSearch"] = "LDAP検索";
$locale["List PageHistory for %s"] = "%s のページ履歴一覧";
$locale["Load File"] = "ファイル読込み";
$locale["Loading '%s'"] = "'%s' を読込み中です。";
$locale["Loading files"] = "ファイルを読込み中です。";
$locale["Lock Page"] = "ページロック";
$locale["Locked"] = "ロックしました";
$locale["Locking pages"] = "ページをロック中です。";
$locale["MIME file %s"] = "MIMEファイル %s";
$locale["Markup"] = "マークアップ";
$locale["Markup cache purged!"] = "マークアップキャッシュを破棄しました!";
$locale["Name"] = "名称";
$locale["New comment."] = "新規コメント";
$locale["New password"] = "新規パスワード";
$locale["Next"] = "次へ";
$locale["Next Month"] = "次の月";
$locale["No changes found"] = "変更点が見つかりませんでした。";
$locale["No changes."] = "変更しませんでした。";
$locale["No revisions found"] = "リビジョンが見つかりません。";
$locale["None"] = "なし";
$locale["Note:"] = "ノート:";
$locale["OldStyleTable"] = "旧スタイルのテーブル";
$locale["PHP syntax highlighting"] = "PHP構文ハイライト";
$locale["Page Locked"] = "ページをロックしました。";
$locale["Page Name"] = "ページ名";
$locale["Page Version"] = "ページバージョン";
$locale["Page now locked."] = "ページはロック中です。";
$locale["Page now unlocked."] = "ページはロック解除中です。";
$locale["Page statistics"] = "ページ統計";
$locale["PageGroup"] = "ページグループ";
$locale["PageHistory"] = "ページ履歴";
$locale["PageHistory for %s"] = "%s のページ履歴";
$locale["PageInfo"] = "ページ情報";
$locale["Password:"] = "パスワード:";
$locale["Personal language:"] = "個人言語";
$locale["Personal theme:"] = "個人テーマ";
$locale["PhotoAlbum"] = "フォトアルバム";
$locale["PhpHighlight"] = "PHPハイライト";
$locale["Please continue editing.  (You'll find your %s at the bottom of the page.)"] = "編集を続けて下さい。 (%s のページの下部も見てください)";
$locale["Plugin"] = "プラグイン";
$locale["Plugin %s disabled."] = "プラグイン %s は無効になっています。";
$locale["Plugin %s failed."] = "プラグイン %s が失敗しました。";
$locale["PluginManager"] = "プラグイン管理";
$locale["Plugins"] = "プラグイン一覧";
$locale["PrevNext"] = "前後";
$locale["Preview"] = "プレビューする";
$locale["Preview only!  Changes not saved."] = "プレビューしているだけです! まだ保存はされていません。";
$locale["Previous"] = "前へ";
$locale["Previous Author"] = "前の編集者";
$locale["Previous Month"] = "前の月";
$locale["Previous Revision"] = "前のリビジョン";
$locale["Printer"] = "プリンター";
$locale["Purge Markup Cache"] = "マークアップキャッシュの破棄";
$locale["RandomPage"] = "ランダムページ";
$locale["Raw HTML"] = "生のHTML";
$locale["RecentChanges"] = "変更履歴";
$locale["Redirect"] = "転送";
$locale["References"] = "参照一覧";
$locale["Remove Page"] = "ページ削除";
$locale["Remove selected pages"] = "選択ページを全て削除";
$locale["Removing pages"] = "ページを削除中です。";
$locale["Return to %s"] = "%s に戻る";
$locale["Revision Not Found"] = "リビジョンが見つかりません";
$locale["Save"] = "保存する";
$locale["Saved: %s"] = "保存しました: %s";
$locale["Score"] = "スコア";
$locale["Search"] = "検索";
$locale["Search for"] = "検索";
$locale["Search:"] = "検索:";
$locale["See %s"] = "%s を参照";
$locale["See: %s"] = "参照: %s";
$locale["Select: "] = "選択:";
$locale["Serialized file %s"] = "シリアライズファイル %s";
$locale["Sidebar"] = "スライドバー";
$locale["Sign In"] = "サインイン";
$locale["Sign Out"] = "サインサウト";
$locale["SiteMap"] = "サイトマップ";
$locale["Sort by %s"] = "%sでソートします。";
$locale["Sound Score"] = "サウンドスコア";
$locale["Submit"] = "送信";
$locale["Submit country"] = "国名送信";
$locale["Submit location"] = "所在地変更";
$locale["Subpage"] = "サブページ";
$locale["Summary"] = "要約";
$locale["Supported languages"] = "サポート言語一覧";
$locale["Supported themes"] = "サポートテーマ一覧";
$locale["Synopsis"] = "要約";
$locale["SystemInfo"] = "システム情報";
$locale["Theme"] = "テーマ";
$locale["Time Zone"] = "タイムゾーン";
$locale["Title Search"] = "タイトル検索";
$locale["TitleSearch"] = "タイトル検索";
$locale["Today"] = "今日";
$locale["Top & bottom toolbars"] = "上部と下部のツールバー";
$locale["Total %d plugins: "] = "合計 %d プラグイン";
$locale["Total of %d themes: "] = "総テーマ数: %d";
$locale["Type it again"] = "もう一度入力";
$locale["Unlock Page"] = "ページロック解除";
$locale["Unlocking pages"] = "ページのロックを解除中です。";
$locale["UpLoad"] = "アップロード";
$locale["Update Preferences"] = "設定を更新しました";
$locale["Upload"] = "アップロード";
$locale["Upload File"] = "ファイル読込み";
$locale["Uploading %s"] = "%s をアップロード中です。";
$locale["Use old markup"] = "古いマークアップを使用";
$locale["User page"] = "ユーザーページ";
$locale["User statistics"] = "ユーザー統計";
$locale["UserId"] = "ユーザーID";
$locale["UserId:"] = "ユーザーID:";
$locale["UserPreferences"] = "ユーザー設定";
$locale["Using directory '%s'"] = "ディレクトリ '%s' を使用しています。";
$locale["Version"] = "バージョン";
$locale["Version "] = "バージョン";
$locale["Version %d"] = "バージョン %d";
$locale["Version %s"] = "バージョン %s";
$locale["View Source"] = "ソースを見る";
$locale["View Source: %s"] = "ソースを見る: %s";
$locale["View the current version"] = "現在のバージョンを表示する";
$locale["View the current version."] = "現在のバージョンを表示する";
$locale["W"] = "幅";
$locale["Warning: You are editing an old revision."] = "警告: あなたは古いリビジョンを編集しています。";
$locale["Width"] = "幅";
$locale["Wiki Name"] = "Wiki名";
$locale["WikiForm: %s: unknown action"] = "WikiForm: '%s' は未知の操作です。";
$locale["cached pagedata:"] = "ページデータをキャッシュ:";
$locale["cached versiondata:"] = "バージョンデータをキャッシュ:";
$locale["compare revisions"] = "リビジョン比較";
$locale["current version"] = "現在のバージョン";
$locale["diff"] = "差分";
$locale["edit area"] = "編集エリア";
$locale["edit this page"] = "ページを編集しています。";
$locale["file %s not found"] = "%s: ファイルが見つかりません。";
$locale["from %s"] = "%s から";
$locale["locked"] = "ロックしました";
$locale["max: %d"] = "最大: %d";
$locale["no cache used"] = "キャッシュを使いません";
$locale["plain file %s"] = "プレインファイル %s";
$locale["previous revision"] = "前のリビジョン";
$locale["saved as "] = "を保存しました。";
$locale["saved as %s"] = "%s を保存しました。";
$locale["today"] = "今日";
$locale["use this plugin"] = "このプラグインを使う";
$locale["version %d"] = "バージョン %d";
$locale["version %s"] = "バージョン %s";
$locale["version <em>%s</em>"] = "バージョン <em>%s</em>";
$locale["yesterday"] =
   "昨日";

?>
